@@ -12,8 +12,10 @@ def load_lazy_fixtures(value, request: pytest.FixtureRequest):
         )
     if isinstance(value, LazyFixtureWrapper):
         return value.load_fixture(request)
-    if isinstance(value, dict):
-        return {key: load_lazy_fixtures(value, request) for key, value in value.items()}
-    elif isinstance(value, (list, tuple, set)):
-        return type(value)([load_lazy_fixtures(value, request) for value in value])
+    # we need to check exact type
+    if type(value) is dict:
+        return {load_lazy_fixtures(key, request): load_lazy_fixtures(val, request) for key, val in value.items()}
+    # we need to check exact type
+    if type(value) in {list, tuple, set}:
+        return type(value)(load_lazy_fixtures(val, request) for val in value)
     return value
